@@ -196,12 +196,19 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time):
+    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time, rth_only=False):
         
         check_bool_dict = self.check_hk_fut_ohlc_args(index, freq, start_date, end_date, rolling_day, rolling_time)
 
         if False not in list(check_bool_dict.values()):
 
+            if freq == '1D':
+                rolling_time = 0
+                if rth_only == True:
+                    freq = freq + '_rth'
+                elif rth_only == False:
+                    freq = freq + '_all'
+
             start_date_dt = datetime.datetime.strptime(str(start_date), '%Y%m%d').date()
             end_date_dt = datetime.datetime.strptime(str(end_date), '%Y%m%d').date()
 
@@ -261,7 +268,7 @@ class Database:
 
                 df_list = []
                 date_time_list_list = []
-
+                date_time_intersect_list = []
                 for result in result_list:
                     sub_df_list = []
                     for item in result:
@@ -272,7 +279,6 @@ class Database:
                     if len(sub_df_list) > 0:
                         df = pd.concat(sub_df_list)
                         df = df.reset_index(drop=True)
-                        print(df)
                         temp_date_list = list(df['date'].unique())
                         temp_date_list.sort()
 
@@ -302,38 +308,78 @@ class Database:
                             front_cut_off_date = 20130501
 
                         if (back_cut_off_date != end_date) or (back_cut_off_date == end_date and back_cut_off_date not in expiry_date_list):
-                            df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
-                            df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
+                            if '1D' not in freq:
+                                df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
+                                df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
+                            else:
+                                df = df[(df['date'] > front_cut_off_date) | (df['date'] == front_cut_off_date)]
+                                df = df[(df['date'] < back_cut_off_date) | (df['date'] == back_cut_off_date)]
 
                         df = df[df['date'] >= start_date]
                         df = df[df['date'] <= end_date]
                         df['date'] = df['date'].astype(str)
-                        df['time'] = df['time'].astype(str)
-                        df['time'] = df['time'].str.zfill(6)
-                        df['datetime'] = df['date'] + ' ' + df['time']
+                        if '1D' not in freq:
+                            df['time'] = df['time'].astype(str)
+                            df['time'] = df['time'].str.zfill(6)
+                            df['datetime'] = df['date'] + ' ' + df['time']
+                        else:
+                            df['datetime'] = df['date']
 
                         df = df.reset_index(drop=True)
                         date_time_list = df['datetime'].to_list()
 
-                        if len(date_time_list_list) > 0:
-                            date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
-                            if len(date_time_intersect) == 0:
-                                df_list.append(df)
+                        if '1D' not in freq:
+                            if len(date_time_list_list) > 0:
+                                date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
+                                if len(date_time_intersect) == 0:
+                                    df_list.append(df)
                         else:
+                            date_time_intersect = (set(date_time_list_list).intersection(date_time_list))
+                            date_time_intersect = list(date_time_intersect)
+                            if len(date_time_intersect) > 0:
+                                date_time_intersect_list.append(date_time_intersect[0])
                             df_list.append(df)
 
                         date_time_list_list += date_time_list
 
-                cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date','RTH']
+                if '1D' not in freq:
+                    cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date','RTH']
+                else:
+                    cols = ['datetime', 'date', 'open', 'high', 'low', 'close', 'volume', 'expiry_date']
                 df = pd.concat(df_list)
 
-                df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
-                df['RTH'] = df['RTH'].astype(bool)
+
+                if '1D' not in freq:
+                    df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
+                    df['RTH'] = df['RTH'].astype(bool)
+                else:
+                    df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d')
 
                 df = df[cols]
+                if '1D' in freq:
+                    drop_index_list = []
+                    df = df.reset_index()
+                    for date_time_intersect in date_time_intersect_list:
+                        check_drop_index_row = df[df['date'] == date_time_intersect]
+                        if len(check_drop_index_row) > 1:
+                            index_0 = check_drop_index_row.index[0]
+                            index_1 = check_drop_index_row.index[1]
+                            expiry_date_0 = df.loc[index_0,'expiry_date']
+                            expiry_date_1 = df.loc[index_1,'expiry_date']
+                            if expiry_date_0 > expiry_date_1:
+                                drop_index_list.append(index_0)
+                            elif expiry_date_0 < expiry_date_1:
+                                drop_index_list.append(index_1)
+                    if len(drop_index_list) > 0:
+                        df = df.drop(drop_index_list, axis=0)
+                    df = df.drop('index', axis=1)
+
                 df = df.set_index(keys='datetime')
                 df = df.sort_index(ascending=True)
 
+                if '1D' not in freq and rth_only == True:
+                    df = df[df['RTH'] == True]
+
                 return df
     
         else:
@@ -1416,7 +1462,7 @@ class Database:
 
     def check_hk_fut_ohlc_args(self, index, freq, start_date, end_date, rolling_day, rolling_time):
 
-        freq_list = ['1T', '5T', '15T']
+        freq_list = ['1T', '5T', '15T', '1D']
         freq_valid = True if freq in freq_list else False
 
         try:
